package de.thdeg.grademanager.gui;

import de.thdeg.grademanager.model.Enrollment;
import de.thdeg.grademanager.model.Student;
import javafx.collections.FXCollections;
import javafx.collections.ObservableList;
import javafx.event.ActionEvent;
import javafx.fxml.FXML;
import javafx.scene.chart.PieChart;
import javafx.scene.control.Label;
import javafx.scene.control.TextField;
import javafx.scene.paint.Paint;
import javafx.scene.text.Text;

import java.io.IOException;

public class StudentStatsController {

    private static String[] colors = {"#57bf08", "#fc0303", "#860061"};

    private static Student student;

    public static void setStudent(Student student) {
        StudentStatsController.student = student;
    }


    @FXML
    protected Text headLine;


    @FXML
    protected TextField studentId;

    @FXML
    protected TextField courseOfStudy;

    @FXML
    protected TextField semester;

    @FXML
    protected PieChart statsDiagram;

    @FXML
    protected Label passedExams;

    @FXML
    protected Label failedExams;

    @FXML
    protected Label openExams;

    @FXML
    protected TextField average;

    @FXML
    protected TextField median;

    @FXML
    protected void initialize() {
        if (student != null) {
            initPieChart();
            courseOfStudy.setText(student.getCoursesOfStudy().getName());
            semester.setText(Integer.toString(student.getSemester()));
            studentId.setText(Integer.toString(student.getId()));
            try{
                average.setText(Double.toString(student.calculateAverage()));
                median.setText(Integer.toString(student.calculateMedian()));
            } catch (Exception e){
                System.out.println(e);
            }
        }
    }

    private void initPieChart() {
        Label[] labels = {passedExams, failedExams, openExams};
        int[] examValues = student.getExamValues();
        headLine.setText("Notenblatt " + student.getFirstName() + " " + student.getLastName());
        ObservableList<PieChart.Data> examStatusPieChart = FXCollections.observableArrayList(
                new PieChart.Data("Bestanden", examValues[0]),
                new PieChart.Data("Offen", examValues[1]),
                new PieChart.Data("Durchgefallen", examValues[2])
        );

        statsDiagram.setData(examStatusPieChart);
        for (int i = 0; i < examStatusPieChart.size(); i++) {
            examStatusPieChart.get(i).getNode().setStyle("-fx-pie-color: " + colors[i] + ";");
            labels[i].setTextFill(Paint.valueOf(colors[i]));
            labels[i].setText(labels[i].getText() + " " + examValues[i]);
        }
    }


    @FXML
    protected void switchToMain(ActionEvent event) throws IOException {
        SwitchWindowHelper.switchTo("Main", event);
    }


}
